import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class SmsReader123458 extends StatefulWidget {
  @override
  _SmsReaderState createState() => _SmsReaderState();
}

class _SmsReaderState extends State<SmsReader123458> {
  static const platform = MethodChannel('hello1234');
  List<String> _smsList = [];
  bool _isLoading = true;
  bool _hasPermission = false;

  @override
  void initState() {
    super.initState();
    _checkPermissionAndReadSms();
  }

  Future<void> _checkPermissionAndReadSms() async {
    bool hasPermission;
    try {
      final bool result =
          await platform.invokeMethod('getPlatformVersion') ?? false;
      hasPermission = result;
    } on PlatformException catch (e) {
      print("Failed to check SMS permission: ${e.message}");
      hasPermission = false;
    }

    if (hasPermission) {
      _getSms();
    } else {
      setState(() {
        _isLoading = false;
        _hasPermission = false;
      });
    }
  }

  Future<void> _getSms() async {
    List<String> smsList = [];
    try {
      final List<dynamic> result =
          await platform.invokeMethod('getPlatformVersion');
      smsList = result.cast<String>();
    } on PlatformException catch (e) {
      print("Failed to get SMS: ${e.message}");
    }

    if (!mounted) return;

    setState(() {
      _smsList = smsList;
      _isLoading = false;
      _hasPermission = true;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('SMS Reader'),
      ),
      body: _isLoading
          ? Center(child: CircularProgressIndicator())
          : _hasPermission
              ? (_smsList.isEmpty
                  ? Center(child: Text('No SMS messages to display'))
                  : ListView.builder(
                      itemCount: _smsList.length,
                      itemBuilder: (context, index) => ListTile(
                        title: Text(_smsList[index]),
                      ),
                    ))
              : Center(child: Text('SMS permission denied')),
    );
  }
}
